# coding:utf-8

import random


# 工具类
class Tools(object):

    # 随机数字
    @staticmethod
    def ran_num(arg=None):
        # 生成六位的数值不在传入的列表中
        num = random.randint(100000, 999999)
        if arg and num in arg:
            return random_num(arg)
        return num

    # 随机字符串
    @staticmethod
    def ran_str(len=None, max_len=None):
        try:
            if len and len >= 1:
                if max_len and max_len > len:
                    len = random.randint(len, max_len)
                return ''.join(random.sample(string.ascii_letters, 1)
                               + random.sample(string.ascii_letters + string.digits, len - 1))
        except Exception:
            pass
        return ''



#!/usr/bin/env python
# coding:utf-8

from setuptools import find_packages, setup

setup(
    name='zqifatools',
    version='0.0.1',
    description='tools',
    long_description=open('README.rst').read(),
    author='Aaron Chu',
    author_email='zqifa@outlook.com',
    maintainer='aaron',
    maintainer_email='zqifa@outlook.com',
    packages=find_packages(),
    platforms=["all"],
    url='https://github.com/zqifa',
    license='BSD License',
    classifiers=[
        'Development Status :: 4 - Beta',
        'Operating System :: OS Independent',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: Implementation :: CPython',
        'Programming Language :: Python :: Implementation :: PyPy'
    ],
)
